DisplayString

Type Alias DisplayString 

pub type DisplayString = OctetString;
Used to model textual information taken from the NVT ASCII character set. By convention, objects with this syntax are declared as having SIZE (0...255)

Aliased Type

pub struct DisplayString(/* private fields */);